Bootswatch: Components

# Bootstrap

HTML, CSS, and JS framework for developing responsive, mobile first projects on the web

# Typography

# Heading 1

## Heading 2

### Heading 3

#### Heading 4

##### Heading 5

###### Heading 6

Vivamus sagittis lacus vel augue laoreet rutrum faucibus dolor auctor. Duis mollis, est non commodo luctus.

Nullam quis risus eget urna mollis ornare vel eu leo. Cum sociis natoque penatibus et magnis dis parturient montes, nascetur ridiculus mus. Nullam id dolor id nibh ultricies vehicula.

Cum sociis natoque penatibus et magnis dis parturient montes, nascetur ridiculus mus. Donec ullamcorper nulla non metus auctor fringilla. Duis mollis, est non commodo luctus, nisi erat porttitor ligula, eget lacinia odio sem nec elit. Donec ullamcorper nulla non metus auctor fringilla.

Maecenas sed diam eget risus varius blandit sit amet non magna. Donec id elit non mi porta gravida at eget metus. Duis mollis, est non commodo luctus, nisi erat porttitor ligula, eget lacinia odio sem nec elit.

### Small text

This line of text is meant to be treated as fine print.

### Bold

The following snippet of text is rendered as bold text.

### Italics

The following snippet of text is rendered as italicized text.

### Emphasis classes

Fusce dapibus, tellus ac cursus commodo, tortor mauris nibh.

Nullam id dolor id nibh ultricies vehicula ut id elit.

Etiam porta sem malesuada magna mollis euismod.

Donec ullamcorper nulla non metus auctor fringilla.

Duis mollis, est non commodo luctus, nisi erat porttitor ligula.

Maecenas sed diam eget risus varius blandit sit amet non magna.

## Abbreviations

### Basic abbreviation

An abbreviation of the word attribute is attr.

### Initialism

HTML is the best thing since sliced bread.

## Addresses

## Blockquotes

> Lorem ipsum dolor sit amet, consectetur adipiscing elit. Integer posuere erat a ante.

> Someone famous in Source Title

> Lorem ipsum dolor sit amet, consectetur adipiscing elit. Integer posuere erat a ante.

> Someone famous in Source Title

## Lists

### Unordered

A list of items in which the order does not explicitly matter.

- Lorem ipsum dolor sit amet
- Consectetur adipiscing elit
- Integer molestie lorem at massa
- Facilisis in pretium nisl aliquet
- Nulla volutpat aliquam velit
  - Phasellus iaculis neque
  - Purus sodales ultricies
  - Vestibulum laoreet porttitor sem
  - Ac tristique libero volutpat at
- Faucibus porta lacus fringilla vel
- Aenean sit amet erat nunc
- Eget porttitor lorem

### Ordered

A list of items in which the order does explicitly matter.

1. Lorem ipsum dolor sit amet
2. Consectetur adipiscing elit
3. Integer molestie lorem at massa
4. Facilisis in pretium nisl aliquet
5. Nulla volutpat aliquam velit
6. Faucibus porta lacus fringilla vel
7. Aenean sit amet erat nunc
8. Eget porttitor lorem

### Unstyled

- Lorem ipsum dolor sit amet
- Consectetur adipiscing elit
- Integer molestie lorem at massa
- Facilisis in pretium nisl aliquet
- Nulla volutpat aliquam velit
  - Phasellus iaculis neque
  - Purus sodales ultricies
  - Vestibulum laoreet porttitor sem
  - Ac tristique libero volutpat at
- Faucibus porta lacus fringilla vel
- Aenean sit amet erat nunc
- Eget porttitor lorem

### Inline

- Lorem ipsum
- Phasellus iaculis
- Nulla volutpat

### Description

Description lists
  A description list is perfect for defining terms.
Euismod
  Vestibulum id ligula porta felis euismod semper eget lacinia odio sem nec elit.
  Donec id elit non mi porta gravida at eget metus.
Malesuada porta
  Etiam porta sem malesuada magna mollis euismod.

#### Horizontal description

Description lists
  A description list is perfect for defining terms.
Euismod
  Vestibulum id ligula porta felis euismod semper eget lacinia odio sem nec elit.
  Donec id elit non mi porta gravida at eget metus.
Malesuada porta
  Etiam porta sem malesuada magna mollis euismod.
Felis euismod semper eget lacinia
  Fusce dapibus, tellus ac cursus commodo, tortor mauris condimentum nibh, ut fermentum massa justo sit amet risus.

# Code

## Inline

For example, `<section>` should be wrapped as inline.

## Basic block

Use `<pre>` for multiple lines of code. Be sure to escape any angle brackets in the code for proper rendering.

    <p>Sample text here...</p>

# Tables

## Basic example

# | First Name | Last Name | Username
--- | --- | --- | ---
1 | Mark | Otto | @mdo
2 | Jacob | Thornton | @fat
3 | Larry | the Bird | @twitter

## Optional classes

### Striped

# | First Name | Last Name | Username
--- | --- | --- | ---
1 | Mark | Otto | @mdo
2 | Jacob | Thornton | @fat
3 | Larry | the Bird | @twitter

### Bordered

Add `.table-bordered` for borders on all sides of the table and cells.

# | First Name | Last Name | Username
--- | --- | --- | ---
1 | Mark | Otto | @mdo
Mark | Otto | @TwBootstrap
2 | Jacob | Thornton | @fat
3 | Larry the Bird | @twitter

### Hover rows

Add `.table-hover` to enable a hover state on table rows within a `<tbody>`.

# | First Name | Last Name | Username
--- | --- | --- | ---
1 | Mark | Otto | @mdo
2 | Jacob | Thornton | @fat
3 | Larry the Bird | @twitter

### Condensed

Add `.table-condensed` to make tables more compact by cutting cell padding in half.

# | First Name | Last Name | Username
--- | --- | --- | ---
1 | Mark | Otto | @mdo
2 | Jacob | Thornton | @fat
3 | Larry the Bird | @twitter

## Contextual table classes

Class | Description
--- | ---
`.success` | Indicates a successful or positive action
`.danger` | Indicates a dangerous or potentially negative action
`.warning` | Indicates a warning that might need attention
`.active` | Applies the hover color to a particular row or cell

# | Column heading | Column heading | Column heading
--- | --- | --- | ---
6 | Column content | Column content | Column content
1 | Column content | Column content | Column content
2 | Column content | Column content | Column content
3 | Default | Primary | Primary
5 | Column content |  | Column content
4 | Column content | Column content | Column content
7 | Column content | Column content | Column content

# Forms

## Basic example

Legend
Email address
Password
File input

Example block-level help text here.

Check me out

## Optional layouts

### Inline form

Remember me

### Horizontal form

Use Bootstrap's predefined grid classes to align labels and groups of form controls in a horizontal layout by adding `.form-horizontal` to the form. Doing so changes `.form-group`s to behave as grid rows, so no need for `.row`.

Email
Password
Remember me

## Supported form controls

Examples of standard form controls supported in an example form layout.

### Inputs

### Textarea

Form control which supports multiple lines of text. Change `rows` attribute as necessary.

### Checkboxes and radios

Checkboxes are for selecting one or several options in a list while radios are for selecting one option from many.

#### Default (stacked)

Option one is this and that—be sure to include why it's great
Option one is this and that—be sure to include why it's great
Option two can be something else and selecting it will deselect option one

#### Inline checkboxes

Use `.checkbox-inline` or `.radio-inline` class to a series of checkboxes or radios for controls appear on the same line.

1 2 3

### Selects

Use the default option, or add `multiple` to show multiple options at once.

## Form control states

Provide feedback to users or visitors with basic feedback states on form controls and labels.

### Input focus

We remove the default `outline` styles on some form controls and apply a `box-shadow` in its place for `:focus`.

### Disabled inputs

Add the `disabled` attribute on an input to prevent user input and trigger a slightly different look.

### Disabled fieldsets

Can't check this

### Validation states

Bootstrap includes validation styles for error, warning, and success states on from controls. To use, add `.has-warning`, `.has-error`, or `.has-success` to the parent element. Any `.control-label`, `.form-control`, and `.help-block` within that element will receive the validation styles.

Input with warning
Input with error
Input with success

#### Icons, labels, and input groups

Manual positioning of feedback icons is required for inputs without a label and for input groups with an add-on on the right. For inputs without labels, adjust the `top`value. For input groups, adjust the `right` value to an appropriate pixel value depending on the width of your addon.

Input with success
Input with warning
Input with error

## Control sizing

Set heights using classes like `.input-lg`, and set widths using grid column classes like `.col-lg-*`.

### Height sizing

Create larger or smaller form controls that match button sizes.

### Column sizing

Wrap inputs in grid columns, or any custom parent element, to easily enforce desired widths.

## Help text

Block level help text for form controls.

A longer block of help text that breaks onto a new line and may extend beyond one line.

# Buttons

## Button options

Use any of the available button classes to quickly create a styled button.

## Button sizes

Fancy larger or smaller buttons? Add `.btn-lg` or `.btn-sm` for additional sizes.

Create block level buttons—those that span the full width of a parent— by adding `.btn-block`.

## Disabled state

Make buttons look unclickable by fading them back 50%.

### Button element

Add the `disabled` attribute to `<button>` buttons.

### Anchor element

Add the `.disabled` class to `<a>` buttons.

Primary link Link

## Using multiple tags

Use the button classes on an `<a>`, `<button>`, or `<input>` element.

Link

# Images

Add classes to an `<img>` element to easily style images in any project.

# Dropdown menus

Toggleable, contextual menu for displaying lists of links. Made interactive with the dropdown JavaScript plugin.

### Example

Wrap the dropdown's trigger and the dropdown menu within `.dropdown`, or another element that declares `position: relative;`. Then add the menu's HTML.

### Aligning the menus

Add `.pull-right` to a `.dropdown-menu` to right align the dropdown menu.

### Dropdown headers

Add a header to break up label sections of actions in any dropdown menu.

### Disabled menu options

Add `.disabled` to a `<li>` in the dropdown to disable the link.

# Button groups

### Basic button group

Wrap a series of buttons with `.btn` in `.btn-group`.

### Multiple button groups

Combine sets of `<div class="btn-group">` into a `<div class="btn-toolbar">` for more complex components.

### Nested button groups

Place buttons groups within button groups when you want dropdown menus mixed with a series of buttons.

### Vertical button groups

Make a set of buttons appear vertically stacked rather than horizontally.

### Justified button groups

Make a group of buttons stretch at the same size to span the entire width of its parent.

Left Middle Right

# Button dropdown menus

Use any button to trigger a dropdown menu by placing it within a `.btn-group` and providing the proper menu markup.

### Single button dropdowns

Turn a button into dropdown toggle with some basic markup changes.

### Split button dropdowns

Similarly, create split button dropdowns with the same markup changes, only with a separate button.

### Works with all button sizes

Button dropdowns work with buttons of all sizes.

### Dropup buttons

Trigger dropdown menus above elements by adding `.dropup` to the parent.

# Input groups

Extend form controls by adding text or buttons before, after, or on both sides of any text-based input. Use `.input-group` with an `.input-group-addon` to prepend or append elements to a `.form-control`.

## Basic input group

@
.00
$ .00

## Optional sizes

Add the relative form sizing classes to the `.input-group-addon`.

@
@
@

## Checkboxes and radio buttons

Place any checkbox or radio option within an input group's addon instead of text.

## Buttons instead of text

Buttons in input groups are a bit different and require one extra level of nesting. Instead of `.input-group-addon`, you'll need to use `.input-group-btn` to wrap the buttons. This is required due to default browser styles that cannot be overridden.

## Buttons with dropdowns

## Segmented dropdown groups

# Navs

Navs available in Bootstrap have shared markup, starting with the base `.nav` class, as well as shared states. Swap modifier classes to switch between each style.

## Tabs

Note the `.nav-tabs` class requires the `.nav` base class.

## Pills

Take that same HTML, but use `.nav-pills` instead:

Pills are also vertically stackable. Just add `.nav-stacked`.

## Options

### Justified links

Easily make tabs or pills equal widths of their parent with `.nav-justified`.

### Disabled state

For any nav component (tabs, pills, or list), add `.disabled` for gray links and no hover effects.

### Component alignment

To align nav links, use the `.pull-left` or `.pull-right` utility classes. Both classes will add a CSS float in the specified direction.

## Dropdowns

Add dropdown menus with a little extra HTML and the dropdowns JavaScript plugin.

### Tabs with dropdowns

### Pills with dropdowns

# Navbar

## Basic navbar

To start, navbars are static (not fixed to the top) and include support for a project name and basic navigation. Place one anywhere within a `.container`, which sets the width of your site and content.

## Navbar components

### Brand

A simple link to show your brand or project name only requires an anchor tag.

### Nav links

Nav items are simple to add via unordered lists.

### Forms

To properly style and position a form within the navbar, add the appropriate classes as shown below. For a default form, include `.navbar-form` and either `.pull-left` or `.pull-right` to properly align it.

### Buttons

For buttons not residing in a `<form>`, add this class to vertically center buttons within a navbar.

### Text

Wrap strings of text in an element with `.navbar-text`, usually on a `<p>` tag for proper leading and color.

### Links

For folks using standard links that are not within the regular navbar navigation component, use the `.navbar-link` class to add the proper colors for the default and inverse navbar options.

### Component alignment

Align nav links, forms, buttons, or text, using the `.pull-left` or `.pull-right` utility classes. Both classes will add a CSS float in the specified direction. To align nav links, put them in a separate `<ul>` with the respective utility class applied.

### Static top navbar

Create a full-width navbar that scrolls away with the page by adding `.navbar-static-top`. Unlike the `.navbar-fixed-*` classes, you do not need to change any padding on the `body`.

## Responsive navbar

To implement a collapsing responsive navbar, wrap your navbar content in a containing div, `.navbar-collapse.collapse`, and add the navbar toggle button, `.navbar-toggle`.

#### Plugin dependency

The responsive navbar requires the collapse plugin to be included in your version of Bootstrap.

## Inverted variation

Modify the look of the navbar by adding `.navbar-inverse`.

# Breadcrumbs

Indicate the current page's location within a navigational hierarchy.

Separators are automatically added in CSS through `:before` and `content`.

# Pagination

Provide pagination links for your site or app with the multi-page pagination component, or the simpler pager alternative.

## Standard pagination

Simple pagination inspired by Rdio, great for apps and search results. The large block is hard to miss, easily scalable, and provides large click areas.

- «
- 1
- 2
- 3
- 4
- 5
- »

### Disabled and active states

Links are customizable for different circumstances. Use `.disabled` for unclickable links and `.active` to indicate the current page.

- «
- 1
- 2
- 3
- 4
- 5
- »

### Sizes

Fancy larger or smaller pagination? Add `.pagination-lg` or `.pagination-sm` for additional sizes.

- «
- 1
- 2
- 3
- 4
- 5
- »

- «
- 1
- 2
- 3
- 4
- 5
- »

- «
- 1
- 2
- 3
- 4
- 5
- »

## Pager

Quick previous and next links for simple pagination implementations with light markup and styles. It's great for simple sites like blogs or magazines.

### Default example

By default, the pager centers links.

- Previous
- Next

### Aligned links

Alternatively, you can align each link to the sides:

- ← Older
- Newer →

### Optional disabled state

Pager links also use the general `.disabled` utility class from the pagination.

- ← Older
- Newer →

# Labels

### Example

# Example heading New

### Available variations

Add any of the below mentioned modifier classes to change the appearance of a label.

Default Primary Success Warning Danger Info

# Badges

Easily highlight new or unread items by adding a `<span class="badge">` to links, Bootstrap navs, and more.

Inbox 42

#### Self collapsing

When there are no new or unread items, badges will simply collapse (via CSS's `:empty` selector) provided no content exists within.

#### Cross-browser compatibility

Badges won't self collapse in Internet Explorer 8 because it lacks support for the `:empty` selector.

#### Adapts to active nav states

Built-in styles are included for placing badges in active states in pill and list navigations.

# Typographic components

## Jumbotron

A lightweight, flexible component to showcase key content on your site. It works well on marketing and content-heavy sites.

# Hello, world!

This is a simple hero unit, a simple jumbotron-style component for calling extra attention to featured content or information.

Learn more

## Page header

A simple shell for an `h1` to appropriately space out and segment sections of content on a page. It can utilize the `h1`'s default `small` element, as well as most other components (with additional styles).

# Example page header Subtext for header

# Thumbnails

Extend Bootstrap's grid system with the thumbnail component to easily display grids of images, videos, text, and more.

### Default thumbnails

By default, Bootstrap's thumbnails are designed to showcase linked images with minimal required markup.

### Custom content thumbnails

With a bit of extra markup, it's possible to add any kind of HTML content like headings, paragraphs, or buttons into thumbnails.

### Thumbnail label

Cras justo odio, dapibus ac facilisis in, egestas eget quam. Donec id elit non mi porta gravida at eget metus. Nullam id dolor id nibh ultricies vehicula ut id elit.

Action Action

### Thumbnail label

Cras justo odio, dapibus ac facilisis in, egestas eget quam. Donec id elit non mi porta gravida at eget metus. Nullam id dolor id nibh ultricies vehicula ut id elit.

Action Action

### Thumbnail label

Cras justo odio, dapibus ac facilisis in, egestas eget quam. Donec id elit non mi porta gravida at eget metus. Nullam id dolor id nibh ultricies vehicula ut id elit.

Action Action

# Alerts

Provide contextual feedback messages for typical user actions with the handful of available and flexible alert messages. For inline dismissal, use the alerts jQuery plugin.

### Default alert

Wrap any text and an optional dismiss button in `.alert` for a basic warning alert message.

#### Ensure proper behavior across all devices

Be sure to use the `<button>` element with the `data-dismiss="alert"` data attribute.

× Warning! Best check yo self, you're not looking too good.

### Contextual alternatives

Add optional classes to change an alert's connotation.

Oh snap! Change a few things up and try submitting again.
Well done! You successfully read this important alert message.
Heads up! This alert needs your attention, but it's not super important.

### Links in alerts

Use the `.alert-link` utility class to quickly provide matching colored links within any alert.

Oh snap! Change a few things up and try submitting again.
Well done! You successfully read this important alert message.
Heads up! This alert needs your attention, but it's not super important.

# Progress bars

Provide up-to-date feedback on the progress of a workflow or action with simple yet flexible progress bars.

#### Cross-browser compatibility

Progress bars use CSS3 transitions and animations to achieve some of their effects. These features are not supported in Internet Explorer 9 and below or older versions of Firefox. Opera 12 does not support animations.

### With Label

60%

### Basic

Default progress bar with a vertical gradient.

### Contextual alternatives

Progress bars use some of the same button and alert classes for consistent styles.

### Striped

Uses a gradient to create a striped effect. Not available in IE8.

### Animated

Add `.active` to `.progress-striped` to animate the stripes right to left. Not available in all versions of IE.

### Stacked

Place multiple bars into the same `.progress` to stack them.

# Media object

Abstract object styles for building various types of components (like blog comments, Tweets, etc) that feature a left- or right-aligned image alongside textual content.

### Default example

The default media allow to float a media object (images, video, audio) to the left or right of a content block.

#### Media heading

Cras sit amet nibh libero, in gravida nulla. Nulla vel metus scelerisque ante sollicitudin commodo. Cras purus odio, vestibulum in vulputate at, tempus viverra turpis. Fusce condimentum nunc ac nisi vulputate fringilla. Donec lacinia congue felis in faucibus.

#### Media heading

Cras sit amet nibh libero, in gravida nulla. Nulla vel metus scelerisque ante sollicitudin commodo. Cras purus odio, vestibulum in vulputate at, tempus viverra turpis. Fusce condimentum nunc ac nisi vulputate fringilla. Donec lacinia congue felis in faucibus.

#### Media heading

Cras sit amet nibh libero, in gravida nulla. Nulla vel metus scelerisque ante sollicitudin commodo. Cras purus odio, vestibulum in vulputate at, tempus viverra turpis. Fusce condimentum nunc ac nisi vulputate fringilla. Donec lacinia congue felis in faucibus.

### Media list

With a bit of extra markup, you can use media inside list (useful for comment threads or articles lists).

- #### Media heading

  Cras sit amet nibh libero, in gravida nulla. Nulla vel metus scelerisque ante sollicitudin commodo. Cras purus odio, vestibulum in vulputate at, tempus viverra turpis.

  #### Nested media heading

  Cras sit amet nibh libero, in gravida nulla. Nulla vel metus scelerisque ante sollicitudin commodo. Cras purus odio, vestibulum in vulputate at, tempus viverra turpis.

  #### Nested media heading

  Cras sit amet nibh libero, in gravida nulla. Nulla vel metus scelerisque ante sollicitudin commodo. Cras purus odio, vestibulum in vulputate at, tempus viverra turpis.

  #### Nested media heading

  Cras sit amet nibh libero, in gravida nulla. Nulla vel metus scelerisque ante sollicitudin commodo. Cras purus odio, vestibulum in vulputate at, tempus viverra turpis.

- #### Media heading

  Cras sit amet nibh libero, in gravida nulla. Nulla vel metus scelerisque ante sollicitudin commodo. Cras purus odio, vestibulum in vulputate at, tempus viverra turpis.

# List group

List groups are a flexible and powerful component for displaying not only simple lists of elements, but complex ones with custom content.

### Basic list group

The most basic list group is simply an unordered list with list items, and the proper classes. Build upon it with the options that follow, or your own CSS as needed.

- Cras justo odio
- Dapibus ac facilisis in
- Morbi leo risus
- Porta ac consectetur ac
- Vestibulum at eros

### With badges

Add the badges component to any list group item and it will automatically be positioned on the right.

- 14 Cras justo odio
- 2 Dapibus ac facilisis in
- 1 Morbi leo risus

### Linked list group

Linkify list group items by using anchor tags instead of list items (that also means a parent `<div>` instead of an `<ul>`). No need for individual parents around each element.

Cras justo odio Dapibus ac facilisis in Morbi leo risus Porta ac consectetur ac Vestibulum at eros

### Custom content

Add nearly any HTML within, even for linked list groups like the one below.

#### List group item heading

Donec id elit non mi porta gravida at eget metus. Maecenas sed diam eget risus varius blandit.

#### List group item heading

Donec id elit non mi porta gravida at eget metus. Maecenas sed diam eget risus varius blandit.

#### List group item heading

Donec id elit non mi porta gravida at eget metus. Maecenas sed diam eget risus varius blandit.

### List Group Item Active

### List Group Demo

Ordinary list item
Success!
Warning!
Danger!

### List Group Demo

Active list item
Success!
Warning!
Danger!

# Panels

While not always necessary, sometimes you need to put your DOM in a box. For those situations, try the panel component.

### Basic panel

By default, all the `.panel` does is apply some basic border and padding to contain some content.

Basic panel example

### Panel with heading

Easily add a heading container to your panel with `.panel-heading`. You may also include any `<h1>`-`<h6>` with a `.panel-title` class to add a pre-styled heading.

Panel heading
Panel content

### Panel title

Panel content

### Panel with footer

Wrap buttons or secondary text in `.panel-footer`.

Panel content

### Contextual alternatives

Like other components, easily make a panel more meaningful to a particular context by adding any of the contextual state classes.

### Panel title

Panel content

### Panel title

Panel content

### Panel title

Panel content

### Panel title

Panel content

### Panel title

Panel content

### With list groups

Easily include full-width list groups within any panel.

Panel heading

Some default panel content here. Nulla vitae elit libero, a pharetra augue. Aenean lacinia bibendum nulla sed consectetur. Aenean eu leo quam. Pellentesque ornare sem lacinia quam venenatis vestibulum. Nullam id dolor id nibh ultricies vehicula ut id elit.

- Cras justo odio
- Dapibus ac facilisis in
- Morbi leo risus
- Porta ac consectetur ac
- Vestibulum at eros

# Wells

### Default well

Use the well as a simple effect on an element to give it an inset effect.

Look, I'm in a well!

### Optional classes

Control padding and rounded corners with two optional modifier classes.

Look, I'm in a well!
Look, I'm in a well!

# Modals

### Live demo

Toggle a modal via JavaScript by clicking the button below. It will slide down and fade in from the top of the page.

#### Modal Heading

#### Text in a modal

Duis mollis, est non commodo luctus, nisi erat porttitor ligula.

#### Popover in a modal

This button should trigger a popover on click.

#### Tooltips in a modal

This link and that link should have tooltips on hover.

#### Overflowing text to show scroll behavior

Cras mattis consectetur purus sit amet fermentum. Cras justo odio, dapibus ac facilisis in, egestas eget quam. Morbi leo risus, porta ac consectetur ac, vestibulum at eros.

Praesent commodo cursus magna, vel scelerisque nisl consectetur et. Vivamus sagittis lacus vel augue laoreet rutrum faucibus dolor auctor.

Aenean lacinia bibendum nulla sed consectetur. Praesent commodo cursus magna, vel scelerisque nisl consectetur et. Donec sed odio dui. Donec ullamcorper nulla non metus auctor fringilla.

Cras mattis consectetur purus sit amet fermentum. Cras justo odio, dapibus ac facilisis in, egestas eget quam. Morbi leo risus, porta ac consectetur ac, vestibulum at eros.

Launch demo modal

# Popovers

Click to toggle popover

success | span | div | Click to toggle popover

# Checkbox / Radio

Checkbox 1 (pre-checked) Checkbox 2 Checkbox 3
Radio 1 (preselected) Radio 2 Radio 3